==> auto-ui-0.3.10.tgz: package/es/spin/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import * as React from 'react';
import cn from 'classnames';
import './style.scss';
var Spin = function (props) {
    var className = props.className, text = props.text, otherProps = __rest(props, ["className", "text"]);
    var loadingSpin = (React.createElement("div", { className: "x-loading__spin" },
        React.createElement("svg", { className: "x-loading__spin_circular", viewBox: "25 25 50 50" },
            React.createElement("circle", { className: "x-loading__spin_path", cx: "50", cy: "50", r: "20", fill: "none", strokeWidth: "2", strokeMiterlimit: "10" }))));
    var composeClassName = cn('x-spin', className);
    return (React.createElement("div", __assign({}, otherProps, { className: composeClassName }),
        loadingSpin,
        !!text && React.createElement("p", { className: "x-spin__text" }, text)));
};
export default Spin;

==> auto-ui-2.4.55.tgz: package/es/spin/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import './style/index.scss';
var Spin = function (props) {
    var className = props.className, otherProps = __rest(props, ["className"]);
    var loadingSpin = (React.createElement("div", { className: "x-loading__spin" },
        React.createElement("span", null),
        React.createElement("span", null),
        React.createElement("span", null)));
    var composeClassName = cn('x-spin', className, {
        'x-spin--primary': props.type === 'primary' || !props.type,
        'x-spin--secondary': props.type === 'secondary',
    });
    return (React.createElement("div", __assign({}, otherProps, { className: composeClassName }), loadingSpin));
};
export default Spin;
